Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type JSONTime ¶
func (JSONTime) MarshalJSON ¶
type UrlInfo ¶
type UrlInfo struct {
// MongoDB _id
Id bson.ObjectId `json:"id,omitempty" bson:"_id"`
// Sort URL of the created for the provided long url by the client
LongUrl string `json:"longUrl,omitempty"`
// Sort URL of the created for the provided long url by the client
ShortUrl string `json:"shortUrl,omitempty"`
// RequestTimeStamp is the time at which collection created
RequestTimeStamp time.Time `json:"requestTimeStamp,omitempty"`
}
UrlInfo holds options for mongodb collection tblShortURL
Click to show internal directories.
Click to hide internal directories.